==> 0.0.61.tar.gz: lib/src/custom_components/custom_table/view.dart <==
import 'package:flutter/material.dart';
import 'package:nirrti/nirrti.dart';
import 'package:nirrti/src/custom_components/custom_table/FilterWidget/view_model.dart';
import 'view_model.dart';

mixin ViewMixin {
  render(BuildContext context, OwlnextTableState state) {
    return Container(
      decoration: BoxDecoration(
        color: Colors.white, 
        borderRadius: Artist().defaultBorderRadius,
      ),
      width: double.infinity,
      padding: Artist().defaultPadding,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start, children: [
        if (state.widget.hasSearch == true || state.widget.filters.isNotEmpty)
        SizedBox(
          height: 40,
          child: Row(
            children: [
              if (state.widget.hasSearch == true)
                SizedBox(
                    height: 40,
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: [
                        state.widget.hasSearch == true
                            ? Row(mainAxisAlignment: MainAxisAlignment.start, crossAxisAlignment: CrossAxisAlignment.center, children: [
                                SizedBox(
                                    width: 250,
                                    height: 40,
                                    child: TextField(
                                        controller: state.searchController,
                                        onSubmitted: state.handleCallbackTrigger,
                                        decoration: InputDecoration(
                                          border: const OutlineInputBorder(),
                                          label: Text('Rechercher', style: Theme.of(context).textTheme.bodySmall),
                                        ),
                                        style: Theme.of(context).textTheme.bodySmall))
                              ])
                            : const SizedBox.shrink(),
                      ],
                    )),
              if (state.widget.hasSearch == true && state.widget.filters.isNotEmpty) const SizedBox(width: 12),
              if (state.widget.filters.isNotEmpty)
                Expanded(
                  child: ListView.separated(
                      scrollDirection: Axis.horizontal,
                      physics: const BouncingScrollPhysics(),
                      padding: const EdgeInsets.all(0),
                      itemCount: state.widget.filters.length,
                      separatorBuilder: (context, index) => SizedBox(width: Artist().listSeparatorHeight),
                      shrinkWrap: true,
                      itemBuilder: (BuildContext context, int index) {
                        return FilterWidget(
                            color: state.widget.filters[index].color,
                            label: state.widget.filters[index].label,
                            callback: () {
                              state.handleChangeCurrentActiveFilter(
                                state.widget.filters[index],
                              );
                            },
                            isActive: state.currentActiveFilter?.label == state.widget.filters[index].label);
                      }),
                )
            ],
          ),
        ),
        if (state.widget.hasSearch == true || state.widget.filters.isNotEmpty) const SizedBox(height: 16),
        if (state.isLoading == true)
        const Align(
          child: OwlnextLoading()
        ),
        if (state.isLoading == false && state.widget.isScrollable == true)
        Expanded(
          child: NotificationListener<ScrollUpdateNotification>(
            child: SingleChildScrollView(
              controller: state.scrollController,
              child: generateTable(context, state)
            ),
            onNotification: (notification) {
              state.handleScrollTriggerNextPage(notification);
              return true;
            },
          )
        ),
        if (state.isLoading == false && state.widget.isScrollable == false)
        generateTable(context, state)
        ]
      )
    );
  }

  Widget generateTable(BuildContext context, OwlnextTableState state) {
    return Column(
      children: [
        Stack(
          children: [
            SizedBox(
                width: double.infinity,
                child: DataTable(
                  showCheckboxColumn: state.widget.hasCheckboxes,
                  columns: <DataColumn>[
                    for (var item in state.widget.headersList)
                      item,
                  ],
                  rows: state.widget.rowsList.isEmpty == true
                      ? <DataRow>[]
                      : <DataRow>[
                          for (var item in state.widget.rowsList)
                            DataRow(
                              selected: item.selected ?? false,
                              onSelectChanged: state.widget.onClickRow != null
                                  ? (bool? selected) {
                                      state.widget.onClickRow!(item.item);
                                    }
                                  : null,
                              cells: <DataCell>[for (var cell in item.widgets) DataCell(cell)],
                            )
                        ],
                )),
            if (state.widget.button != null)
              Positioned(
                  top: 15,
                  right: 5,
                  child: InkWell(
                      child: MouseRegion(
                          cursor: SystemMouseCursors.click,
                          child: GestureDetector(
                              onTap: () {
                                state.widget.button!();
                              },
                              child: Container(
                                  decoration: BoxDecoration(color: Theme.of(context).colorScheme.surfaceVariant, borderRadius: BorderRadius.circular(100)),
                                  padding: const EdgeInsets.all(2),
                                  child: const Align(
                                      child: Icon(
                                    Icons.add,
                                    color: Colors.white,
                                    size: 20,
                                  )))))))
          ],
        ),
        if (state.widget.rowsList.isEmpty) const SizedBox(width: double.infinity, child: Text('Aucune donnée', textAlign: TextAlign.center, style: TextStyle(fontStyle: FontStyle.italic)))
      ],
    );
  }
}

==> 0.0.82.tar.gz: lib/src/custom_components/custom_table/view.dart <==
import 'package:flutter/material.dart';
import 'package:nirrti/nirrti.dart';
import 'package:nirrti/src/custom_components/custom_table/FilterWidget/view_model.dart';
import 'view_model.dart';

mixin ViewMixin {
  render(BuildContext context, OwlnextTableState state) {
    return Container(
      decoration: BoxDecoration(
        color: Colors.white, 
        borderRadius: Artist().defaultBorderRadius,
      ),
      width: double.infinity,
      padding: Artist().defaultPadding,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start, children: [
        if (state.widget.hasSearch == true || state.widget.filters.isNotEmpty)
        SizedBox(
          height: 40,
          child: Row(
            children: [
              if (state.widget.hasSearch == true)
                SizedBox(
                    height: 40,
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: [
                        state.widget.hasSearch == true
                            ? Row(mainAxisAlignment: MainAxisAlignment.start, crossAxisAlignment: CrossAxisAlignment.center, children: [
                                SizedBox(
                                    width: 250,
                                    height: 40,
                                    child: TextField(
                                        controller: state.searchController,
                                        onSubmitted: state.handleCallbackTrigger,
                                        decoration: InputDecoration(
                                          border: const OutlineInputBorder(),
                                          label: Text('Rechercher', style: Theme.of(context).textTheme.bodySmall),
                                        ),
                                        style: Theme.of(context).textTheme.bodySmall))
                              ])
                            : const SizedBox.shrink(),
                      ],
                    )),
              if (state.widget.hasSearch == true && state.widget.filters.isNotEmpty) const SizedBox(width: 12),
              if (state.widget.filters.isNotEmpty)
                Expanded(
                  child: ListView.separated(
                      scrollDirection: Axis.horizontal,
                      physics: const BouncingScrollPhysics(),
                      padding: const EdgeInsets.all(0),
                      itemCount: state.widget.filters.length,
                      separatorBuilder: (context, index) => SizedBox(width: Artist().listSeparatorHeight),
                      shrinkWrap: true,
                      itemBuilder: (BuildContext context, int index) {
                        return FilterWidget(
                            color: state.widget.filters[index].color,
                            label: state.widget.filters[index].label,
                            callback: () {
                              state.handleChangeCurrentActiveFilter(
                                state.widget.filters[index],
                              );
                            },
                            isActive: state.currentActiveFilter?.label == state.widget.filters[index].label);
                      }),
                )
            ],
          ),
        ),
        if (state.widget.hasSearch == true || state.widget.filters.isNotEmpty) const SizedBox(height: 16),
        if (state.isLoading == true)
        const Align(
          child: OwlnextLoading()
        ),
        if (state.isLoading == false && state.widget.isScrollable == true)
        Expanded(
          child: NotificationListener<ScrollUpdateNotification>(
            child: SingleChildScrollView(
              controller: state.scrollController,
              child: generateTable(context, state)
            ),
            onNotification: (notification) {
              state.handleScrollTriggerNextPage(notification);
              return true;
            },
          )
        ),
        if (state.isLoading == false && state.widget.isScrollable == false)
        generateTable(context, state)
        ]
      )
    );
  }

  Widget generateTable(BuildContext context, OwlnextTableState state) {
    return Column(
      children: [
        Stack(
          children: [
            SizedBox(
                width: double.infinity,
                child: DataTable(
                  showCheckboxColumn: state.widget.hasCheckboxes,
                  columns: <DataColumn>[
                    for (var item in state.widget.headersList)
                      item,
                  ],
                  rows: state.widget.rowsList.isEmpty == true
                      ? <DataRow>[]
                      : <DataRow>[
                          for (var item in state.widget.rowsList)
                            DataRow(
                              selected: item.selected ?? false,
                              onSelectChanged: state.widget.onClickRow != null
                                  ? (bool? selected) {
                                      state.widget.onClickRow!(item.item);
                                    }
                                  : null,
                              cells: <DataCell>[for (var cell in item.widgets) DataCell(cell)],
                            )
                        ],
                )),
            if (state.widget.button != null)
              Positioned(
                  top: 15,
                  right: 5,
                  child: InkWell(
                      child: MouseRegion(
                          cursor: SystemMouseCursors.click,
                          child: GestureDetector(
                              onTap: () {
                                state.widget.button!();
                              },
                              child: Container(
                                  decoration: BoxDecoration(color: Theme.of(context).colorScheme.surfaceContainerHighest, borderRadius: BorderRadius.circular(100)),
                                  padding: const EdgeInsets.all(2),
                                  child: const Align(
                                      child: Icon(
                                    Icons.add,
                                    color: Colors.white,
                                    size: 20,
                                  )))))))
          ],
        ),
        if (state.widget.rowsList.isEmpty) const SizedBox(width: double.infinity, child: Text('Aucune donnée', textAlign: TextAlign.center, style: TextStyle(fontStyle: FontStyle.italic)))
      ],
    );
  }
}
